@@ -15,6 +15,7 @@ logger = logging.getLogger(__name__)
 class User:
     def __init__(self, regapp_userinfo, extensive=False):
         if args.verbose:
+            print("User record")
             print(json.dumps(regapp_userinfo, sort_keys=True, indent=4, separators=(',', ': ')))
 
         self.userinfo      = regapp_userinfo
@@ -48,8 +49,12 @@ class User:
             self.primary_group = None
 
         self.groups        = []
-        for group in regapp_userinfo['secondaryGroups']:
-            self.groups.append(Group(group))
+        try:
+            for group in regapp_userinfo['secondaryGroups']:
+                self.groups.append(Group(group))
+        except KeyError:
+            # we have no secondary groups for this user
+            pass
 
         for key in ['email', 'uidNumber', 'userStatus', 'createdAt', 'updatedAt', 'externalId', 'eppn']:
             try:
@@ -65,6 +70,9 @@ class User:
         reg_info = get_user_registrations_from_external_id(self.externalId)
         self.reg = []
         for reg in reg_info:
+            if args.verbose:
+                print("Registry Info:")
+                print(json.dumps(reg, sort_keys=True, indent=4, separators=(',', ': ')))
             self.reg.append(Registry(reg))
 
     def __repr__(self, info=True, groups=False, sshkeys=False, extensive=False):
@@ -137,39 +145,60 @@ class Group:
 
 class Registry:
     def  __init__ (self, reg_info):
+        if args.verbose:
+            print("Registry Info:")
+            print(json.dumps(reg_info, sort_keys=True, indent=4, separators=(',', ': ')))
         self.reg_info = reg_info
-        keys = [ "agreedTime" , "createdAt" , "id" , "lastAccessCheck" , "lastReconcile",\
-                 "lastStatusChange" , "registryStatus" , "serviceShortName" , "updatedAt", \
-                 "userEmailAddress" , "version", "registryValues"]
+        self.keys = [ "agreedTime" , "createdAt" , "id" , "lastAccessCheck" , "lastReconcile",
+                 "lastStatusChange" , "registryStatus" , "serviceShortName" , "updatedAt",
+                 "userEmailAddress" , "userEmailAddresses" , "version", "registryValues",
+                 "userEppn", "userId", "UserUidNumber"]
+        self.registry_keys = [ "cn" , "description" , "gidNumber" , "givenName" , "groupName",
+                           "homeDir" , "localUid" , "mail" , "sambaEnabled" , "sn" , "uidNumber"]
+    
+        self.display_keys = [ "userEmailAddress" , "registryStatus",
+                             "userEppn" ]
+        self.display_registry_keys = [ "localUid" , "uidNumber"]
 
-        # "registryValues": {
-        #     "cn"
-        #     "description"
-        #     "gidNumber"
-        #     "givenName"
-        #     "groupName"
-        #     "homeDir"
-        #     "localUid"
-        #     "mail"
-        #     "sambaEnabled"
-        #     "sn"
-        #     "uidNumber"
-        # },
-        for key in keys:
+        self.extensive_display_keys = ["createdAt" , "id" ,
+                             "registryStatus" , "serviceShortName" ,
+                             "userEmailAddress" , "userEmailAddresses" , "version",
+                             "userEppn", "userId", "UserUidNumber"]
+        self.extensive_display_registry_keys = [ "cn" , "description" , "gidNumber" , "givenName" , "groupName",
+                           "homeDir" , "localUid" , "mail" , "sambaEnabled" , "sn" , "uidNumber"]
+
+        self.very_extensive_display_keys = ["createdAt" , "id" ,
+                             "registryStatus" , "serviceShortName" ,
+                             "userEmailAddress" , "userEmailAddresses" , "version",
+                             "userEppn", "userId", "UserUidNumber"]
+        self.very_extensive_display_registry_keys = [ "cn" , "description" , "gidNumber" , "givenName" , "groupName",
+                           "homeDir" , "localUid" , "mail" , "sambaEnabled" , "sn" , "uidNumber"]
+
+        for key in self.keys:
             try:
                 setattr(self, key, reg_info[key])
             except KeyError:
                 setattr(self, key, "Not set")
 
     def __repr__(self, extensive=False):
-        rv = ""
-        rv += F"{self.id} - "
-        rv += F"{self.registryStatus:13} - "
-        if extensive:
-            rv += F"{self.lastStatusChange:30}- "
-            rv += F"{self.createdAt:30}- "
-        rv += F"{self.serviceShortName:10}- "
-        rv += F"{self.registryValues['localUid']}"
+        """Nicely display the registry values"""
+        rv = "\n"
+        display_keys = self.display_keys
+        display_registry_keys = self.display_registry_keys
+        if extensive > 1:
+            display_keys = self.extensive_display_keys
+            display_registry_keys = self.extensive_display_registry_keys
+        if not extensive or extensive < 1:
+            if self.registryStatus != 'ACTIVE':
+                return ""
+
+        for key in display_keys:
+            rv += F"{key:20}: {getattr(self, key)}\n"
+
+        registryValues = self.registryValues
+        for key in display_registry_keys:
+            rv += F"  {key:18}: {registryValues[key]}\n"
+
         return rv
     def info (self, extensive=False):
         return self.__repr__(extensive)
